@@ -1,8 +1,9 @@
 #! /usr/bin/env python3
 
 """
-    mkv-this: input text, output markovified text.
-    Copyright (C) 2020 mousebot@riseup.net.
+    mkv-this: input text and/or url, output markovified text.
+
+    Copyright (C) 2020 martianhiatus@riseup.net.
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -17,22 +18,16 @@
     You should have received a copy of the GNU General Public License
     along with this program.  If not, see <https://www.gnu.org/licenses/>.
 """
-"""
-    a (very basic) script to markovify local and/or remote text files and
-    output a user-specified number of sentences to a local text file.
-    see --help for other options.
-"""
+
 
 import os
-import requests
-import markovify
 import sys
 import argparse
-import html2text
+from .functions import URL, convert_html, read, mkbtext, mkbnewline, writesentence, writeshortsentence
 
 # argparse
 def parse_the_args():
-    parser = argparse.ArgumentParser(prog="mkv-this", description="markovify one or two local or remote text files and output the results to a local text file.",
+    parser = argparse.ArgumentParser(prog="mkv-this", description="markovify local text files or URLs and output the results to a local text file.",
                                      epilog="may you find many prophetic énoncés in your virtual bird guts! Here, this is not at all the becomings that are connected... so if you want to edit it like a bot yourself, it is trivial.")
 
     # positional args:
@@ -44,7 +39,7 @@ def parse_the_args():
     # optional args:
     parser.add_argument('-s', '--state-size', help="the number of preceeding words used to calculate the probability of the next word. defaults to 2, 1 makes it more random, 3 less so. > 4 will likely have little effect.", type=int, default=2)
     parser.add_argument(
-        '-n', '--sentences', help="the number of 'sentences' to output. defaults to 5.", type=int, default=5)
+        '-n', '--sentences', help="the number of 'sentences' to output. defaults to 5. NB: if your text has no initial caps, a 'sentence' will be a paragraph.", type=int, default=5)
     parser.add_argument(
         '-l', '--length', help="set maximum number of characters per sentence.", type=int)
     parser.add_argument(
@@ -58,8 +53,7 @@ def parse_the_args():
     # switches
     parser.add_argument(
         '-u', '--URL', help="infile is a URL instead.", action='store_true')
-    parser.add_argument('-f', '--no-well-formed', help="don't enforce 'well_formed': allow the inclusion of sentences containing []{}()""'' in the markov model. might filth up your text, eg if it contains 'smart' quotes.", action='store_false')
-    # store_false = default to True.
+    parser.add_argument('-f', '--well-formed', help="enforce 'well_formed': discard sentences containing []{}()""'' from the markov model. use if output is filthy.", action='store_true') # store_false = default to True.
     parser.add_argument(
         '--newline', help="sentences in input file end with newlines \
         rather than full stops.", action='store_true')
@@ -67,73 +61,9 @@ def parse_the_args():
 
     return parser.parse_args()
 
-# fetch/read/build/write fns:
 
-
-def URL(insert):
-    try:
-        req = requests.get(insert)
-        req.raise_for_status()
-    except Exception as exc:
-        print(f': There was a problem: {exc}.\n: Please enter a valid URL')
-        sys.exit()
-    else:
-        print(': fetched URL.')
-        return req.text
-
-
-def convert_html(html):
-    h2t = html2text.HTML2Text()
-    h2t.ignore_links = True
-    h2t.ignore_images = True
-    h2t.ignore_emphasis = True
-    print(': URL converted to text')
-    return h2t.handle(html)
-
-
-def read(infile):
-    try:
-        with open(infile, encoding="utf-8") as f:
-            return f.read()
-    except UnicodeDecodeError:
-        with open(infile, encoding="latin-1") as f:
-            return f.read()
-    except FileNotFoundError:
-        print(fnf)
-        sys.exit()
-
-
-def mkbtext(texttype):
-    return markovify.Text(texttype, state_size=args.state_size,
-                          well_formed=args.no_well_formed)
-
-
-def mkbnewline(texttype):
-    return markovify.NewlineText(texttype, state_size=args.state_size,
-                                 well_formed=args.no_well_formed)
-
-
-def writesentence(tmodel):
-    for i in range(args.sentences):
-        output = open(args.outfile, 'a')  # append
-        # short:
-        if args.length:
-            output.write(str(tmodel.make_short_sentence(
-                tries=2000, max_overlap_ratio=args.overlap,
-                max_chars=args.length)) + '\n\n')
-        # normal:
-        else:
-            output.write(str(tmodel.make_sentence(
-                tries=2000, max_overlap_ratio=args.overlap,
-                max_chars=args.length)) + '\n\n')
-    output.write(str('*\n\n'))
-    output.close()
-
-
-# make args + fnf avail to all:
+# make args avail:
 args = parse_the_args()
-fnf = ': error: file not found. please provide a path to a really-existing \
-    file!'
 
 
 def main():
@@ -141,12 +71,11 @@ def main():
     if args.combine or args.combine_URL:
         if args.combine:
             # get raw text as a string for both:
-            #            try:
             # infile is URL:
             if args.URL:
                 html = URL(args.infile)
                 text = convert_html(html)
-            # or normal:
+                # or normal:
             else:
                 text = read(args.infile)
             # read -c file:
@@ -154,7 +83,6 @@ def main():
 
         # if -C, combine it w infile/URL:
         elif args.combine_URL:
-            #            try:
             # infile is URL:
             if args.URL:
                 html = URL(args.infile)
@@ -169,17 +97,21 @@ def main():
         # build the models + a combined model:
         # with --newline:
         if args.newline:
-            text_model = mkbnewline(text)
-            ctext_model = mkbnewline(ctext)
+            text_model = mkbnewline(text, args.state_size, args.well_formed)
+            ctext_model = mkbnewline(ctext, args.state_size, args.well_formed)
         # no --newline:
         else:
-            text_model = mkbtext(text)
-            ctext_model = mkbtext(ctext)
+            text_model = mkbtext(text, args.state_size, args.well_formed)
+            ctext_model = mkbtext(ctext, args.state_size, args.well_formed)
 
         combo_model = markovify.combine(
             [text_model, ctext_model], [1, args.weight])
 
-        writesentence(combo_model)
+        # write it combo!
+        if args.length:
+            writeshortsentence(combo_model, args.sentences, args.outfile, args.overlap, args.length)
+        else:
+            writesentence(combo_model, args.sentences, args.outfile, args.overlap, args.length)
 
     # if no -c/-C, do normal:
     else:
@@ -195,14 +127,18 @@ def main():
         # Build the model:
         # if --newline:
         if args.newline:
-            text_model = mkbnewline(text)
+            text_model = mkbnewline(text, args.state_size, args.well_formed)
         # no --newline:
         else:
-            text_model = mkbtext(text)
+            text_model = mkbtext(text, args.state_size, args.well_formed)
 
-        writesentence(text_model)
+        # write it!
+        if args.length:
+            writeshortsentence(text_model, args.sentences, args.outfile, args.overlap, args.length)
+        else:
+            writesentence(text_model, args.sentences, args.outfile, args.overlap, args.length)
 
-    print('\n: The options you used are as follows:\n')
+    print('\n:                :\n')
     for key, value in vars(args).items():
         print(': ' + key.ljust(15, ' ') + ':  ' + str(value).ljust(10))
     if os.path.isfile(args.outfile):
@@ -214,6 +150,5 @@ def main():
     sys.exit()
 
 
-# for testing:
 if __name__ == '__main__':
     main()
