@@ -1,7 +1,8 @@
 #! /usr/bin/env python3
 """
-    mkv-this-dir: input a directory, output markovified text based on all its text files.
-    Copyright (C) 2020 mousebot@riseup.net.
+    mkv-this-dir: input a directory (+ optional url), output markovified text based on all its text files.
+
+    Copyright (C) 2020 martianhiatus@riseup.net.
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -17,16 +18,11 @@
     along with this program.  If not, see <https://www.gnu.org/licenses/>.
 """
 
-"""
-a (very basic) script to collect all text files in a directory, markovify them and output a user-specified number of sentences to a text file.
-"""
 
 import os
-import markovify
 import sys
 import argparse
-import html2text
-import requests
+from .functions import URL, convert_html, read, mkbtext, mkbnewline, writesentence, writeshortsentence
 
 # argparse
 def parse_the_args():
@@ -39,83 +35,25 @@ def parse_the_args():
 
     # optional args:
     parser.add_argument('-s', '--state-size', help="the number of preceeding words the probability of the next word depends on. defaults to 2, 1 makes it more random, 3 less so.", type=int, default=2)
-    parser.add_argument('-n', '--sentences', help="the number of 'sentences' to output. defaults to 5.", type=int, default=5)
+    parser.add_argument('-n', '--sentences', help="the number of 'sentences' to output. defaults to 5. NB: if your text has no initial caps, a 'sentence' will be a paragraph.", type=int, default=5)
     parser.add_argument('-l', '--length', help="set maximum number of characters per sentence.", type=int)
     parser.add_argument('-o', '--overlap', help="the amount of overlap allowed between original text and the output, expressed as a radio between 0 and 1. lower values make it more random. defaults to 0.5", type=float, default=0.5)
     parser.add_argument('-C', '--combine-URL', help="provide a URL to be combined with the input dir")
     parser.add_argument('-w', '--weight', help="specify the weight to be given to the second text provided with --combine. defaults to 1, and the weight of the initial text is also 1. setting this to 1.5 will place 50 percent more weight on the second text. setting it to 0.5 will place less.", type=float, default=1)
 
     # switches
-    parser.add_argument('-f', '--no-well-formed', help="don't enforce 'well_formed', ie allow the inclusion of sentences with []{}()""'' in them in the markov model. this might filth up your text, especially if it contains 'smart' quotes.", action='store_false')
+    parser.add_argument('-f', '--well-formed', help="enforce 'well_formed', doscard sentences with []{}()""'' from the markov model. use if output is filthy.", action='store_true')
     # store_false = default to True.
     parser.add_argument('--newline', help="sentences in input file end with newlines rather than with full stops.", action='store_true')
     # store_true = default to False, become True if flagged.
 
     return parser.parse_args()
 
-# retch, read, build, write fns:
 
-
-def URL(insert):
-    try:
-        req = requests.get(insert)
-        req.raise_for_status()
-    except Exception as exc:
-        print(f': There was a problem: {exc}.\n: Please enter a valid URL')
-        sys.exit()
-    else:
-        print(': fetched URL.')
-        return req.text
-
-
-def convert_html(html):
-    h2t = html2text.HTML2Text()
-    h2t.ignore_links = True
-    h2t.ignore_images = True
-    h2t.ignore_emphasis = True
-    print(': URL converted to text')
-    return h2t.handle(html)
-
-
-def read(infile):
-    try:
-        with open(infile, encoding="utf-8") as f:
-            return f.read()
-    except UnicodeDecodeError:
-        with open(infile, encoding="latin-1") as f:
-            return f.read()
-    except FileNotFoundError:
-        print(fnf)
-        sys.exit()
-
-def mkbtext(texttype):
-    return markovify.Text(texttype, state_size=args.state_size,
-                          well_formed=args.no_well_formed)
-
-def mkbnewline(texttype):
-    return markovify.NewlineText(texttype, state_size=args.state_size,
-                          well_formed=args.no_well_formed)
-
-def writesentence(tmodel):
-    for i in range(args.sentences):
-        output = open(args.outfile, 'a')  # append
-        # short:
-        if args.length:
-            output.write(str(tmodel.make_short_sentence(
-                tries=2000, max_overlap_ratio=args.overlap,
-                max_chars=args.length)) + '\n\n')
-        # normal:
-        else:
-            output.write(str(tmodel.make_sentence(
-                tries=2000, max_overlap_ratio=args.overlap,
-                max_chars=args.length)) + '\n\n\n')
-    output.write(str('*\n\n'))
-    output.close()
-
-    
-# make args avail to all:
+# make args avail:
 args = parse_the_args()
 
+
 def main():
     #create a list of files to concatenate:
     matches = []
@@ -153,33 +91,42 @@ def main():
         # Build combo model:
         # if --newline:
         if args.newline:
-            text_model = mkbnewline(text)
-            ctext_model = mkbnewline(ctext)
+            text_model = mkbnewline(text, args.state_size, args.well_formed)
+            ctext_model = mkbnewline(ctext, args.state_size, args.well_formed)
         # no --newline:
         else:
-            text_model = mkbtext(text)
-            ctext_model = mkbtext(ctext)
+            text_model = mkbtext(text, args.state_size, args.well_formed)
+            ctext_model = mkbtext(ctext, args.state_size, args.well_formed)
 
         combo_model = markovify.combine(
             [text_model, ctext_model], [1, args.weight])
 
-        writesentence(combo_model)
-        
-    # no combining:
+        # write it combo!
+        if args.length:
+            writeshortsentence(combo_model, args.sentences, args.outfile, args.overlap, args.length)
+        else:
+            writesentence(combo_model, args.sentences, args.outfile, args.overlap, args.length)
+
+        # no combining:
     else:
         # Build model:
         # if --newline:
         if args.newline:
-            text_model = mkbnewline(text)
+            text_model = mkbnewline(text, args.state_size, args.well_formed)
         # no --newline:
         else:
-            text_model = mkbtext(text)
+            text_model = mkbtext(text, args.state_size, args.well_formed)
 
-        writesentence(text_model)
+        # write it!
+        if args.length:
+            writeshortsentence(text_model, args.sentences, args.outfile, args.overlap, args.length)
+        else:
+            writesentence(text_model, args.sentences, args.outfile, args.overlap, args.length)
         
     os.unlink(batchfile)
 
-    print('\n: The options you used are as follows:\n')
+#    print('\n: The options you used are as follows:\n')
+    print('\n:                :\n')
     for key, value in vars(args).items():
         print(': ' + key.ljust(15, ' ') + ':  ' + str(value).ljust(10))
     if os.path.isfile(args.outfile):
@@ -190,6 +137,5 @@ def main():
 
     sys.exit()
     
-# for testing:
 if __name__ == '__main__':
     main()
